GeneEnrich
==========

Installation and Usage
----------------------

##### Manual installation (Without Update Database Function)

~~~~~~~~~~~~~~~~~~~bash

The recommended installation is as follows:

.. code-block:: bash

   (GeneEnrich) $ pip install GeneEnrich

~~~~~~~~~~~~~~~~~~~

##### Manual installation

~~~~~~~~~~~~~~~~~~~bash
The recommended installation is as follows:
conda_pkgs.txt can be found in https://github.com/WhiteRabBio/GeneEnrich

.. code-block:: bash

   (GeneEnrich) $ mamba create -n GeneEnrich -y --file conda_pkgs.txt
   (GeneEnrich) $ pip install GeneEnrich

~~~~~~~~~~~~~~~~~~~

##### Usage

```bash
usage: GeneEnrich run_go [-h] --input INPUT_FILE --prefix PREFIX --output OUTPUT_DIR --species SPECIES --type
                         {scanpy_deg,seuratv3_deg,seuratv4_deg,list} [--updown {up,down,both}] [--pvalue PVALUE] [--qvalue QVALUE]

Run enrichment based on GO database.

options:
  -h, --help            show this help message and exit
  --input INPUT_FILE    Choosen from `Differential Expression Gene file generated by Scanpy or Seurat` And `One column gene list
  --prefix PREFIX       Prefix of output results.
  --output OUTPUT_DIR   Output file location.
  --species SPECIES     Support human or mouse.
  --type {scanpy_deg,seuratv3_deg,seuratv4_deg,list}
                        DEG file or Gene list file
  --updown {up,down,both}
                        Use up-regulated gene\down-regulated gene\ both, if DEG provided.
  --pvalue PVALUE       Pvalue cutoff for enrichment
  --qvalue QVALUE       Qvalue cutoff for enrichment

```



```bash
usage: GeneEnrich run_kegg [-h] --input INPUT_FILE --prefix PREFIX --output OUTPUT_DIR --species SPECIES --type
                           {scanpy_deg,seuratv3_deg,seuratv4_deg,list} [--updown {up,down,both}] [--pvalue PVALUE] [--qvalue QVALUE]

Run enrichment based on KEGG database.

options:
  -h, --help            show this help message and exit
  --input INPUT_FILE    Choosen from `Differential Expression Gene file generated by Scanpy or Seurat` And `One column gene list
  --prefix PREFIX       Prefix of output results.
  --output OUTPUT_DIR   Output file location.
  --species SPECIES     Support human or mouse.
  --type {scanpy_deg,seuratv3_deg,seuratv4_deg,list}
                        DEG file or Gene list file
  --updown {up,down,both}
                        Use up-regulated gene\down-regulated gene\ both, if DEG provided.
  --pvalue PVALUE       Pvalue cutoff for enrichment
  --qvalue QVALUE       Qvalue cutoff for enrichment

```



```bash
usage: GeneEnrich update_db [-h] --database {KEGG,GO} --species SPECIES --version {python,R}

Update GO and KEGG database.

options:
  -h, --help            show this help message and exit
  --database {KEGG,GO}  Choosen from KEGG or GO database to update.
  --species SPECIES     Support human or mouse.
  --version {python,R}  If python, will download latest database from website. If R, will extract database from existing database
                        info.
```



##### Citation

Yu, Guangchuang et al. “clusterProfiler: an R package for comparing biological themes among gene clusters.” *Omics : a journal of integrative biology* vol. 16,5 (2012): 284-7. doi:10.1089/omi.2011.0118